"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.executeSonarAnalysis = executeSonarAnalysis;
var _child_process = require("child_process");
var _sonarReportSummary = require("./sonarReportSummary");
var _logger = require("../../utils/logger");
var _getSonarProperties = require("./getSonarProperties");
var _getFileUtils = require("../eslint/getFileUtils");
/**
 * @note javascript code  to start sonar Server
 */

/**
 * @function executeSonarAnalysis - start sonar analysis and send metric to sonar server
 * @param {Object} cliParams - Object represent cli Argument 
 */

function executeSonarAnalysis(cliParams) {
  _logger.Logger.createLogFile();
  const command = (0, _getSonarProperties.getSonarProperties)(cliParams);
  const child_process = (0, _child_process.spawn)("java", command);
  _logger.Logger.start('Sending report to SonarQube ...');
  child_process.stdout.on("data", data => {
    _logger.Logger.emit(data);
  });
  child_process.stderr.on("data", errorOut => {
    // error will appear here
    // Logger.error(Logger.FAILURE_TYPE, errorOut);
  });
  child_process.on("error", error => {
    _logger.Logger.cliLog(_logger.Logger.SUCCESS_TYPE, 'failed to send report to sonarQube ...');
    _logger.Logger.error(_logger.Logger.FAILURE_TYPE, `Error: ${error.message}`);
  });
  child_process.on("close", code => {
    code === 0 ? global.analytics.sonarQubeStatus = false : null;
    _logger.Logger.stop();
    (0, _sonarReportSummary.writeSummaryOfLint)(cliParams);
    _logger.Logger.cliLog(_logger.Logger.SUCCESS_TYPE, 'SonarQube analysis completed...');
    _logger.Logger.cliLog(_logger.Logger.SUCCESS_TYPE, `Report ${code === 0 ? "successfully" : "failed"} sent to the server :  Status - ${code === 0 ? "Success" : "Failure"}`);
    code === 0 ? _logger.Logger.cliLog(_logger.Logger.PATH_TYPE, `Report URL - ${(0, _sonarReportSummary.getSummaryOfLint)(cliParams).reportUrl}`) : null;
    global.analytics.reportStatus ? _logger.Logger.cliLog(_logger.Logger.INFO_TYPE, `JSON report Path - ${(0, _getFileUtils.getLintReportPath)()}`) : null;
    code === 0 ? _logger.Logger.cliLog(_logger.Logger.INFO_TYPE, `SonarQube Artifacts Path - ${(0, _getSonarProperties.getSonarArtifactsDir)()}`) : null;
  });
}