"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getLintStatus = getLintStatus;
exports.getSummaryOfLint = getSummaryOfLint;
exports.writeSummaryOfLint = writeSummaryOfLint;
var _path = _interopRequireDefault(require("path"));
var _fileUtils = require("../../utils/fileUtils");
var _getFileUtils = require("../eslint/getFileUtils");
var _getSonarProperties = require("./getSonarProperties");
/**
 * @function getSummaryOfLint -  get summary of lint process 
 * @param {Object} cliParams - Object represent cli Argument 
 * @returns {Object}
 */

function getSummaryOfLint(cliParams) {
  var $projectName = (0, _getSonarProperties.getProjectName)(cliParams);
  const {
    sonar_hostURL
  } = (0, _fileUtils.getLintConfiguration)();
  return {
    projectName: $projectName,
    reportUrl: global.analytics.sonarQubeStatus === false ? `${sonar_hostURL}/project/issues?id=${$projectName}&resolved=false` : sonar_hostURL,
    jsonReportPath: (0, _getFileUtils.getLintReportPath)().toString()
  };
}

/**
 * @function getLintStatus - get status of lint based on report
 * @param {Boolean} impactBased - argument from cli to decide to lint based on impact or not
 * @returns {Object}
 */

function getLintStatus(impactBased) {
  if (impactBased == false) {
    return {
      reportStatus: true,
      pipelineStatus: 'passed'
    };
  }
  return global.analytics;
}

/**
 * @function writeSummaryOfLint - write a summary of lint report ans it's status
 * @param {Object} cliParams -  Object represent cli Argument 
 * @returns {void}
 */

function writeSummaryOfLint(cliParams) {
  const {
    impactBased
  } = (0, _fileUtils.getLintConfiguration)();
  (0, _fileUtils.writeFileContents)(_path.default.resolve(process.cwd(), "lint-report", "lint-summary.json"), JSON.stringify({
    ...getSummaryOfLint(cliParams),
    ...getLintStatus(impactBased)
  }));
}